# Simulation Template for Swarm Intelligence Cup Beta Phase

Welcome to the Swarm Intelligence Cup (SIC)! This repository contains a template for how you can run a simulation and add your own agent behaviors. You can find more information about the cup on our [website](https://lab42.global/sic-new-homepage/).

## Getting Started

To get started, simply click on the badge below. This will take you to a Google Colab notebook where you can run the simulation. You will need to sign in with a Google account to use Colab. If you do not have a Google account, you can create one for free.

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/lab42-global/sic42-template/blob/main/sic-template.ipynb)

## Instructions

Once you open the notebook, follow the instructions and code blocks step by step. You do not need to worry too much about the details of the simulation setup—just focus on the tasks at hand and the specific areas of the code where you'll be implementing your solutions. Note that you can run each code block by clicking the play button on the left side of the code block or by pressing `Shift+Enter`. 

In case you get stuck, you can refer to the [documentation](https://sic.lab42.global) for more information about the simulation environment and the available APIs.

Don't forget to sign up for the competition at [lab42.global/sic-new-registration/](https://lab42.global/sic-new-registration/
)!

## Questions and Support

If you have any questions or need support, please reach out to us.

Good luck and happy coding!